@@ -16,16 +16,21 @@
 
 import os
 
+HTTPLIB_CA_CERTS_PATH = os.environ.get('HTTPLIB_CA_CERTS_PATH')
 LINUX_PATH = '/etc/ssl/certs/ca-certificates.crt'
 
 
 def get():
     """Return a path to a certificate authority file.
     """
+    if HTTPLIB_CA_CERTS_PATH:
+        CA_CERTS_PATH = HTTPLIB_CA_CERTS_PATH
+    else:
+        CA_CERTS_PATH = LINUX_PATH
     # FIXME(dhellmann): Assume Linux for now, add more OSes and
     # platforms later.
-    if os.path.exists(LINUX_PATH):
-        return LINUX_PATH
+    if os.path.exists(CA_CERTS_PATH):
+        return CA_CERTS_PATH
     # Fall back to the httplib2 default behavior by raising an
     # ImportError if we have not found the file.
     raise ImportError()
